==> deepamehta-core-4.4.2-sources.jar: de/deepamehta/core/service/Migration.java <==
package de.deepamehta.core.service;

import de.deepamehta.core.Type;
import de.deepamehta.core.util.DeepaMehtaUtils;

import java.io.InputStream;



public abstract class Migration {

    // ---------------------------------------------------------------------------------------------- Instance Variables

    protected DeepaMehtaService dms;

    // -------------------------------------------------------------------------------------------------- Public Methods

    public void setCoreService(DeepaMehtaService dms) {
        this.dms = dms;
    }

    public abstract void run();

    // ----------------------------------------------------------------------------------------------- Protected Methods

    // Convenience method ### FIXME: belongs to Webclient module
    protected final void addTopicTypeSetting(String topicTypeUri, String setting, Object value) {
        addTypeSetting(dms.getTopicType(topicTypeUri), setting, value);
    }

    // Convenience method ### FIXME: belongs to Webclient module
    protected final void addAssociationTypeSetting(String assocTypeUri, String setting, Object value) {
        addTypeSetting(dms.getAssociationType(assocTypeUri), setting, value);
    }

    // ---

    // Convenience method ### FIXME: belongs to Webclient module
    protected final void addTypeSetting(Type type, String setting, Object value) {
        type.getViewConfig().addSetting("dm4.webclient.view_config", "dm4.webclient." + setting, value);
    }

    // ---

    protected final void readMigrationFile(String migrationFile) {
        InputStream migrationIn = getClass().getResourceAsStream(migrationFile);
        DeepaMehtaUtils.readMigrationFile(migrationIn, migrationFile, dms);
    }
}

==> deepamehta-core-4.8.3-sources.jar: de/deepamehta/core/service/Migration.java <==
package de.deepamehta.core.service;

import de.deepamehta.core.DeepaMehtaType;
import de.deepamehta.core.service.ModelFactory;



public abstract class Migration {

    // ---------------------------------------------------------------------------------------------- Instance Variables

    protected CoreService dm4;
    protected ModelFactory mf;

    // -------------------------------------------------------------------------------------------------- Public Methods

    // ### TODO: make this internal. Define a public Migration interface?
    public void setCoreService(CoreService dm4) {
        this.dm4 = dm4;
        this.mf = dm4.getModelFactory();
    }

    public abstract void run();

    // ----------------------------------------------------------------------------------------------- Protected Methods

    // Convenience method ### FIXME: belongs to Webclient module
    protected final void addTopicTypeSetting(String topicTypeUri, String setting, Object value) {
        addTypeSetting(dm4.getTopicType(topicTypeUri), setting, value);
    }

    // Convenience method ### FIXME: belongs to Webclient module
    protected final void addAssociationTypeSetting(String assocTypeUri, String setting, Object value) {
        addTypeSetting(dm4.getAssociationType(assocTypeUri), setting, value);
    }

    // ---

    // Convenience method ### FIXME: belongs to Webclient module
    protected final void addTypeSetting(DeepaMehtaType type, String setting, Object value) {
        type.getViewConfig().addSetting("dm4.webclient.view_config", "dm4.webclient." + setting, value);
    }
}
